@@ -4,8 +4,7 @@
 #
 # DeVeDe-NG is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 3 of the License, or
-# (at your option) any later version.
+# the Free Software Foundation; either version 3 of the License.
 #
 # DeVeDe-NG is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -74,7 +73,7 @@ class file_movie(devedeng.interface_manager.interface_manager):
         self.add_toggle("copy_sound", False)
         self.add_toggle("is_mpeg_ps", False)
         self.add_toggle("no_reencode_audio_video", False)
-        if (self.disc_type == "divx") or (self.disc_type == "mkv"):
+        if (self.disc_type == "divx") or (self.disc_type == "mkv") or (self.config.disc_type == "hevc"):
             self.add_toggle("gop12", False)
         else:
             self.add_toggle("gop12", True)
@@ -260,7 +259,7 @@ class file_movie(devedeng.interface_manager.interface_manager):
 
     def set_final_rates(self):
 
-        if (self.disc_type == "divx") or (self.disc_type == "mkv"):
+        if (self.disc_type == "divx") or (self.disc_type == "mkv") or (self.config.disc_type == "hevc"):
             self.audio_rate_auto = 192
         elif (self.disc_type == "vcd") or (self.disc_type == "svcd") or (self.disc_type == "cvd"):
             self.audio_rate_auto = 224
@@ -305,7 +304,7 @@ class file_movie(devedeng.interface_manager.interface_manager):
 
         # for divx or matroska, if the size and the aspect ratio is automatic,
         # just don't change them
-        if ((self.disc_type == "divx") or (self.disc_type == "mkv")) and (final_size == "size_auto") and (self.aspect_ratio == "aspect_auto"):
+        if ((self.disc_type == "divx") or (self.disc_type == "mkv") or (self.config.disc_type == "hevc")) and (final_size == "size_auto") and (self.aspect_ratio == "aspect_auto"):
             self.width_midle = self.original_width
             self.width_final = self.original_width
             self.height_midle = self.original_height
@@ -473,7 +472,7 @@ class file_movie(devedeng.interface_manager.interface_manager):
         self.wframe_division_chapters = self.builder.get_object(
             "frame_division_chapters")
 
-        if (self.disc_type == "dvd") or (self.disc_type == "divx") or (self.disc_type == "mkv"):
+        if (self.disc_type == "dvd") or (self.disc_type == "divx") or (self.disc_type == "mkv") or (self.config.disc_type == "hevc"):
             self.waudio_rate.set_upper(448.0)
         else:
             self.waudio_rate.set_upper(384.0)
@@ -556,7 +555,7 @@ class file_movie(devedeng.interface_manager.interface_manager):
             self.wcopy_sound.hide()
             self.wnotebook.remove_page(5)
             self.wnotebook.remove_page(1)
-        elif (self.disc_type == 'mkv'):
+        elif (self.disc_type == 'mkv') or (self.config.disc_type == "hevc"):
             self.wshow_in_menu.hide()
             self.wframe_division_chapters.hide()
             self.wnotebook.remove_page(5)
